summaryrefslogtreecommitdiff
path: root/perl/Wallet
diff options
context:
space:
mode:
authorRuss Allbery <rra@stanford.edu>2007-08-27 16:46:50 +0000
committerRuss Allbery <rra@stanford.edu>2007-08-27 16:46:50 +0000
commit10c21db62ffe14c6f208cbfa938f72bc4876f594 (patch)
tree5289375b51af835e36153aeacc41ced86f56c021 /perl/Wallet
parent8fc83f27c6c0845e2e2319cd0e2f3ea321bbb105 (diff)
Rename Wallet::ACL to Wallet::ACL::Base to preserve the Wallet::ACL
package name for higher-level ACL handling.
Diffstat (limited to 'perl/Wallet')
-rw-r--r--perl/Wallet/ACL/Base.pm (renamed from perl/Wallet/ACL.pm)10
-rw-r--r--perl/Wallet/ACL/Krb5.pm2
2 files changed, 6 insertions, 6 deletions
diff --git a/perl/Wallet/ACL/Krb5.pm b/perl/Wallet/ACL/Krb5.pm
index e8d8921..bc03405 100644
--- a/perl/Wallet/ACL/Krb5.pm
+++ b/perl/Wallet/ACL/Krb5.pm
@@ -16,7 +16,7 @@ require 5.006;
use strict;
use vars qw(@ISA $VERSION);
-@ISA = qw(Wallet::ACL);
+@ISA = qw(Wallet::ACL::Base);
# This version should be increased on any code change to this module. Always
# use two digits for the minor version with a leading zero if necessary so
diff --git a/perl/Wallet/ACL.pm b/perl/Wallet/ACL/Base.pm
index 5258d85..0670537 100644
--- a/perl/Wallet/ACL.pm
+++ b/perl/Wallet/ACL/Base.pm
@@ -1,4 +1,4 @@
# Wallet::ACL -- Parent class for wallet ACL verifiers.
# $Id$
#
# Written by Russ Allbery <rra@stanford.edu>
@@ -10,7 +10,7 @@
# Modules and declarations
##############################################################################
-package Wallet::ACL;
+package Wallet::ACL::Base;
require 5.006;
use strict;
@@ -56,12 +56,12 @@ __END__
=head1 NAME
-Wallet::ACL - Generic parent class for wallet ACL verifiers
+Wallet::ACL::Base - Generic parent class for wallet ACL verifiers
=head1 SYNOPSIS
package Wallet::ACL::Simple
- @ISA = qw(Wallet::ACL);
+ @ISA = qw(Wallet::ACL::Base);
sub check {
my ($self, $principal, $acl) = @_;
return ($principal eq $acl) ? 1 : 0;
@@ -69,7 +69,7 @@ Wallet::ACL - Generic parent class for wallet ACL verifiers
=head1 DESCRIPTION
-Wallet::ACL is the generic parent class for wallet ACL verifiers. It
+Wallet::ACL::Base is the generic parent class for wallet ACL verifiers. It
provides default functions and behavior and all ACL verifiers should inherit
from it. It is not used directly.
@@ -1,4 +1,4 @@
-# Wallet::ACL -- Parent class for wallet ACL verifiers.
+# Wallet::ACL::Base -- Parent class for wallet ACL verifiers.
# $Id$
#